<template>
  <div class="back-layout">
    <div
      v-if="isMobile && !menuShrink"
      class="back-layout__backdrop"
      @click="onBackdropClick"
    />
    <base-sidebar></base-sidebar>
    <div class="back-layout__right">
      <base-nav></base-nav>
      <tags-view v-if="enableTagView"></tags-view>
      <div class="back-layout__main">
        <nuxt />
      </div>
    </div>
  </div>
</template>

<script>
import { mapState } from 'vuex'
import TagsView from '@/components/tags-view'
export default {
  components: {
    TagsView,
  },
  middleware: ['auth', 'permission'],
  data() {
    return {
      enableTagView: this.$config.enableTagView,
    }
  },
  computed: {
    ...mapState({
      isMobile: (state) => state.app.isMobile,
      menuShrink: (state) => state.app.menuShrink,
    }),
  },
  methods: {
    onBackdropClick() {
      this.$store.commit('app/SET_MENU_SHRINK', true)
    },
  },
}
</script>

<style scoped lang="scss">
.back-layout {
  width: 100%;
  height: 100%;
  overflow: hidden;
  display: flex;
  &__backdrop {
    background-color: rgba(0, 0, 0, 0.3);
    width: 100%;
    top: 0;
    height: 100%;
    position: absolute;
    z-index: 999;
  }
  &__right {
    flex: 1;
    height: 100%;
    overflow: hidden;
    position: relative;
    display: flex;
    flex-direction: column;
  }
  &__main {
    flex: 1;
    background-color: $bg-color;
    overflow: auto;
    padding: 20px;
  }
}
</style>
